@@ -1,21 +1,12 @@
 # -*- coding: utf-8 -*-
 
-import json
-import urllib
-import urllib.request
-import uuid
-
 from django.conf import settings
 from django.contrib.auth import authenticate, login, logout
 from django.contrib.auth.models import User
-from django.contrib.auth.decorators import login_required
 from django.http import HttpResponseRedirect
 from django.shortcuts import render
 from django.urls import reverse
 
-from .models import Log
-from foledol.django.utils import get_param, check_length, send_mail2
-
 
 def user_login(request):
     error = None
