@@ -8,6 +8,10 @@ from .utils import get_local_date
 
 
 def log(ref, model, action, user=None, old='', new='', transaction=None):
+
+    def too_big(value):
+        return value and isinstance(value, str) and len(value) > 126
+
     _log = Log(user=get_user_or_superuser(user))
     _log.date = get_local_date()
     _log.ref = ref
@@ -22,12 +26,16 @@ def log(ref, model, action, user=None, old='', new='', transaction=None):
             if old[key] != new[key]:
                 diff[key] = (old[key], new[key])
         for key in diff.keys():
-            _log_item = LogItem()
-            _log_item.log = _log
-            _log_item.key = key
-            _log_item.old = diff[key][0]
-            _log_item.new = diff[key][1]
-            _log_item.save()
+            if not too_big(diff[key][0]) and not too_big(diff[key][1]):
+                try:
+                    _log_item = LogItem()
+                    _log_item.log = _log
+                    _log_item.key = key
+                    _log_item.old = diff[key][0]
+                    _log_item.new = diff[key][1]
+                    _log_item.save()
+                except Exception as ex:
+                    print("Exception:" + str(ex))
 
 
 def logs(ref, model):
