@@ -10,12 +10,12 @@ from ..utils import remove_file
 
 class BarCode:
 
-    def __init__(self, uid, value):
-        path = os.path.join(settings.MEDIA_ROOT, 'bc39', uid.replace('/', '-'))
+    def __init__(self, uid, name, value, folder):
+        path = os.path.join(settings.MEDIA_ROOT, folder, uid.replace('/', '-'))
         self.path_bc = path + '.png'
         remove_file(self.path_bc)
 
-        bc39 = barcode.get('code39', value, writer=ImageWriter(), options={'add_checksum': False})
+        bc39 = barcode.get(name, value, writer=ImageWriter(), options={'add_checksum': False})
         bc39.save(path, {"module_width": 0.3})
 
         bc39 = Image.open(self.path_bc)
@@ -31,4 +31,5 @@ class BarCode:
 
 
 def create_bc39(uid, value):
-    return BarCode(uid, value) if uid and value else None
+    return BarCode(uid, 'code39', value, 'bc39') if uid and value else None
+
