@@ -9,7 +9,7 @@ class ColumnTable(TableView):
     def __init__(self):
         super().__init__(Column, [
             TableColumn('label', "Libellé")
-        ], path='django:columns', search=True)
+        ], path='django/columns', search=True)
         self.update = 'django:column_update'
         self.create = 'django:column_create'
 
