@@ -10,13 +10,13 @@ class GridTables(TableView):
         super().__init__(Grid, [
             TableColumn('name', "Nom", sortable=True),
             TableColumn('table', "Table", method="table_as_str")
-        ], path='django:grids', search=True, sort='name_asc')
+        ], path='django/grids', search=True, sort='name_asc')
         self.update = 'django:grid_update'
         self.create = 'django:grid_create'
 
     def select(self, grids, search, order_by):
         if len(search) > 0:
-            grids = Grid.objects.filter(name=search)
+            grids = Grid.objects.filter(name__contains=search)
         if order_by == 'name_asc':
             return grids.order_by('name')
         elif order_by == 'name_desc':
